@@ -41,8 +41,6 @@
 
 #define KXMLGUI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KXMLGUI_NO_DEPRECATED) && !defined(KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KXMLGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KXMLGUI_NO_DEPRECATED
-#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KXMLGUI_NO_DEPRECATED_WARNINGS
 #  define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KXMLGUI_DEPRECATED
-#  define KXMLGUI_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KXMLGUI_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KXMLGUI_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
